#coding=utf-8

import urllib
import pytz
import datetime
from hashlib import sha256
from hmac import HMAC
import xmltodict
import requests


class Lazada(object):
    '''
    Lazada order api
    '''

    def __init__(self, app_key=None, account_id=None,url =None):
        self.app_key = str(app_key)
        self.account_id = str(account_id)
        self.url =str(url)
        self.headers = {"Accept": "text/xml", "Content-Type": "text/html", "charset": "UTF-8"}

    def get_order_list(self, item):
        '''
        获取所有pending的订单
        @param item:
        @return:
        '''
        try:
            item['Version'] = '1.0'
            item['UserID'] = self.account_id
            item['Timestamp'] = datetime.datetime.now(pytz.timezone('UTC')).isoformat()
            item['Action'] = 'GetOrders'
            concatenated = urllib.urlencode(sorted(item.items()))
            sign = HMAC(self.app_key, concatenated, sha256).hexdigest()
            resp = requests.get(self.url+'?'+concatenated+'&Signature='+sign, headers=self.headers, timeout=120)
#             print resp.text
            resp.raise_for_status()
            doc = xmltodict.parse(resp.text)
            if doc.get('SuccessResponse').get('Body').get('Orders'):
                return doc.get('SuccessResponse').get('Body').get('Orders').get('Order')
        except Exception as e:
            print e

    def get_order(self, item):
        '''
        根据订单号获取订单的详细信息
        @param item:
        @return:
        '''
        try:
            print '-----------------get_order---------------------------'
            item['Version'] = '1.0'
            item['UserID'] = str(self.account_id)
            item['Timestamp'] = datetime.datetime.now(pytz.timezone('UTC')).isoformat()
            item['Action'] = 'GetOrderItems'
            # concatenated = urllib.urlencode(sorted(item.items()))
            # sign = HMAC(self.app_key, concatenated, sha256).hexdigest()
            # resp = requests.get(self.url+'?'+concatenated+'&Signature='+sign, headers=self.headers, timeout=120)
            # resp.raise_for_status()
            # doc = xmltodict.parse(resp.text)
            # if doc.get('SuccessResponse').get('Body').get('OrderItems'):
            #     return doc.get('SuccessResponse').get('Body').get('OrderItems').get('OrderItem')
            doc = self.__make_call(item)
            if doc.get('SuccessResponse').get('Body').get('OrderItems'):
                return doc.get('SuccessResponse').get('Body').get('OrderItems').get('OrderItem')
        except Exception as e:
            print e

    def __make_call(self,params):

        concatenated = urllib.urlencode(sorted(params.items()))
        sign = HMAC(self.app_key, concatenated, sha256).hexdigest()
        resp = requests.get(self.url + '?' + concatenated + '&Signature=' + sign, headers=self.headers, timeout=120)
        resp.raise_for_status()
        doc = xmltodict.parse(resp.text)
        return doc